# hopy
A high level language for predicate evaluation on JSON using JsonPath expressions

## Getting started

### Prerequisites
- python3.7+

### Installation
- Install the package using pip.
    ```bash
    pip install hopy
    ```

## License
This project is licensed under the Apache License - see the [LICENSE.md](LICENSE.md) file for details

## Acknowledgements
- Inspired from [santanusinha/hope](https://github.com/santanusinha/hope)
- Default JsonPath implementation [jsonpath-ng](https://pypi.org/project/jsonpath-ng/)
